%
%   EODdurfftphases.m
%       Calculates EOD duration based on 2% of peak criteria
%       and peak power frequency
%
%

%% Clear Workspace
clear all
close all
%% Load Data File
filetype = input('(E)OD file or (S)tim file? ','s');
if filetype=='E',
    [filename, pathname] = uigetfile('*.eod.mat', 'Open file');
    load (fullfile(pathname,filename), '-mat');
    cd(char(pathname))
elseif filetype=='S',
    [filename, pathname] = uigetfile('*.stim.wav.mat', 'Open file');
    load (fullfile(pathname,filename), '-mat');
    cd(char(pathname))
    eod = stimwave;
else
    error('You must choose either (E)OD or (S)tim file!!!');
end
times = (1000/srate).*[1:1:length(eod)];
% eod=[eod(1:5,:); eod(7:11,:)];
%% Normalize EODs to peak-to-peak of 1 and get mean
[a,b] = size(eod);
if filetype=='E',
    disp(['There are a total of ' sprintf('%3g',a) ' EODs'])
%     neod = input('Which EOD? ');
elseif filetype=='S',
    neod = 1;
end
for j=1:a
    eod(j,:)=eod(j,:)-mean(eod(j,:));
    norm_eod(j,:) = eod(j,:)./(max(eod(j,:))-min(eod(j,:)));

%% Plot data
f1 = figure('Name','EOD Waveform','NumberTitle','off','Position',[50 150 1000 550],'Color','w');
a1 = axes;
plot(a1,times,norm_eod(j,:),'k-','LineWidth',2)
box(a1,'off')
xlabel(a1,'Time (s)')
ylabel(a1,'Normalized Potential')
hold(a1,'on')
xlim([min(times) max(times)])
zoom on

%% Detect start and end of EOD and calculate duration
[peakval(j),peakind(j)] = max(abs(norm_eod(j,:)));
thold = 0.02;
for i=1:peakind(j),
    if abs(norm_eod(j,i))>=thold,
        startind(j) = i-1;
        break
    end
end
for i=length(norm_eod(j,:)):-1:peakind(j),
    if abs(norm_eod(j,i))>=thold,
        endind(j) = i+1;
        break
    end
end
eoddur(j) = times(endind(j))-times(startind(j));
end

%% Display Results
plot(a1,times(startind(j)),norm_eod(j,startind(j)),'g*',times(endind(j)),norm_eod(j,endind(j)),'g*')
plot(a1,times(p1_end(j)),norm_eod(j,p1_end(j)),'b*',times(p2_end(j)),norm_eod(j,p2_end(j)),'r*')
plot([0 5],[0.02 0.02],'m--')
plot([0 5],[-0.02 -0.02],'m--')
plot([0 5],[0 0],'m')
if ~(isnan(p3_end(j)))
    plot(a1,times(p3_end(j)),norm_eod(j,p3_end(j)),'c*')
end


disp('EOD total durations (ms)')
eoddur'

disp('Average EOD total duration (ms)')
disp('SD EOD total duration (ms)')

if (a>10)
    [mean(eoddur(1:10)); std(eoddur(1:10))]
else
    [mean(eoddur); std(eoddur)]
end