% Measure instantaneous phase of spontaneous KO oscillations
clear all
close all

%% Open file
[filename, pathname] = uigetfile('*.wave.KOrec.mat', 'Open file');
load (fullfile(pathname,filename), '-mat');
cd(char(pathname))
%% Define time
time_rec=[1:1:length(response)].*(1000/srate_rec);
[nreps m]=size(response);
%% Hilbert transform
for i=1:nreps
    hx_r(i,:)=hilbert(response(i,:));
    inst_phase_r(i,:)=(angle(hx_r(i,:)));
    hx_s(i,:)=hilbert(stimulus(i,:));
    inst_phase_s(i,:)=(angle(hx_s(i,:)));
end
for i=1:nreps
    figure
    a(1)=subplot(2,1,1);
    plot(time_rec,response(i,:))
    hold on
    plot(time_rec,stimulus(i,:),'r')
    xlabel('Time (ms)')
    ylabel('Voltage (mV)')
    title(i)
    a(2)=subplot(2,1,2);
    plot(time_rec,inst_phase_r(i,:))
    hold on
    plot(time_rec,inst_phase_s(i,:),'r')
    xlabel('Time (ms)')
    ylabel('Phase (rad)')
    title(i)
    linkaxes(a,'x')
end

%% Probability distributions
inst_phase_r_deg=inst_phase_r./pi*180;
inst_phase_s_deg=inst_phase_s./pi*180;

centers=[-175:10:175];

%All reps
for i=1:nreps
    [hist_r(i,:) bincents]=hist(inst_phase_r_deg(i,:),centers);
    [hist_s(i,:) bincents]=hist(inst_phase_s_deg(i,:),centers);
    
    hist_r_norm(i,:)=hist_r(i,:)./sum(hist_r(i,:));
    hist_s_norm(i,:)=hist_s(i,:)./sum(hist_s(i,:));
    
end

for r=1:length(hist_r_norm(1,:))
    prod_norm_1(r,:)=hist_r_norm(1,r).*hist_s_norm(1,:);
    prod_1(r,:)=hist_r(1,r).*hist_s(1,:);
    prod_norm_2(r,:)=hist_r_norm(2,r).*hist_s_norm(2,:);
    prod_2(r,:)=hist_r(2,r).*hist_s(2,:);
    prod_norm_3(r,:)=hist_r_norm(3,r).*hist_s_norm(3,:);
    prod_3(r,:)=hist_r(3,r).*hist_s(3,:);
    prod_norm_4(r,:)=hist_r_norm(4,r).*hist_s_norm(4,:);
    prod_4(r,:)=hist_r(4,r).*hist_s(4,:);
    prod_norm_5(r,:)=hist_r_norm(5,r).*hist_s_norm(5,:);
    prod_5(r,:)=hist_r(5,r).*hist_s(5,:);
    prod_norm_15(r,:)=hist_r_norm(1,r).*hist_s_norm(5,:);
    prod_15(r,:)=hist_r(1,r).*hist_s(5,:);
    prod_norm_51(r,:)=hist_r_norm(5,r).*hist_s_norm(1,:);
    prod_51(r,:)=hist_r(5,r).*hist_s(1,:);
end

%% Joint probability distribution
both_phases_1(:,1)=inst_phase_r(1,:)';
both_phases_1(:,2)=inst_phase_s(1,:)';
both_phases_deg_1(:,1)=inst_phase_r_deg(1,:)';
both_phases_deg_1(:,2)=inst_phase_s_deg(1,:)';

both_phases_2(:,1)=inst_phase_r(2,:)';
both_phases_2(:,2)=inst_phase_s(2,:)';
both_phases_deg_2(:,1)=inst_phase_r_deg(2,:)';
both_phases_deg_2(:,2)=inst_phase_s_deg(2,:)';

both_phases_3(:,1)=inst_phase_r(3,:)';
both_phases_3(:,2)=inst_phase_s(3,:)';
both_phases_deg_3(:,1)=inst_phase_r_deg(3,:)';
both_phases_deg_3(:,2)=inst_phase_s_deg(3,:)';

both_phases_4(:,1)=inst_phase_r(4,:)';
both_phases_4(:,2)=inst_phase_s(4,:)';
both_phases_deg_4(:,1)=inst_phase_r_deg(4,:)';
both_phases_deg_4(:,2)=inst_phase_s_deg(4,:)';

both_phases_5(:,1)=inst_phase_r(5,:)';
both_phases_5(:,2)=inst_phase_s(5,:)';
both_phases_deg_5(:,1)=inst_phase_r_deg(5,:)';
both_phases_deg_5(:,2)=inst_phase_s_deg(5,:)';

both_phases_15(:,1)=inst_phase_r(1,:)';
both_phases_15(:,2)=inst_phase_s(5,:)';
both_phases_deg_15(:,1)=inst_phase_r_deg(1,:)';
both_phases_deg_15(:,2)=inst_phase_s_deg(5,:)';

both_phases_51(:,1)=inst_phase_r(5,:)';
both_phases_51(:,2)=inst_phase_s(1,:)';
both_phases_deg_51(:,1)=inst_phase_r_deg(5,:)';
both_phases_deg_51(:,2)=inst_phase_s_deg(1,:)';

centers=[-175:10:175];
cnt_1 = hist3(both_phases_deg_1, {centers centers});
cnt_norm_1=cnt_1./(sum(sum(cnt_1)));

cnt_2 = hist3(both_phases_deg_2, {centers centers});
cnt_norm_2=cnt_2./(sum(sum(cnt_2)));

cnt_3 = hist3(both_phases_deg_3, {centers centers});
cnt_norm_3=cnt_3./(sum(sum(cnt_3)));

cnt_4 = hist3(both_phases_deg_4, {centers centers});
cnt_norm_4=cnt_4./(sum(sum(cnt_4)));

cnt_5 = hist3(both_phases_deg_5, {centers centers});
cnt_norm_5=cnt_5./(sum(sum(cnt_5)));

cnt_15 = hist3(both_phases_deg_15, {centers centers});
cnt_norm_15=cnt_15./(sum(sum(cnt_15)));

cnt_51 = hist3(both_phases_deg_51, {centers centers});
cnt_norm_51=cnt_51./(sum(sum(cnt_51)));


figure
subplot(2,1,1),imagesc(centers,centers,prod_norm_1)
xlabel('Phase (degrees)')
ylabel('Phase (degrees)')
title('Rep 1: Product of individual probability distributions')
subplot(2,1,2),imagesc(centers,centers,cnt_norm_1)
xlabel('Phase (degrees)')
ylabel('Phase (degrees)')
title('Rep 1: Normalized joint probability')

figure
subplot(2,1,1),imagesc(centers,centers,prod_norm_2)
xlabel('Phase (degrees)')
ylabel('Phase (degrees)')
title('Rep 2: Product of individual probability distributions')
subplot(2,1,2),imagesc(centers,centers,cnt_norm_2)
xlabel('Phase (degrees)')
ylabel('Phase (degrees)')
title('Rep 2: Normalized joint probability')

figure
subplot(2,1,1),imagesc(centers,centers,prod_norm_3)
xlabel('Phase (degrees)')
ylabel('Phase (degrees)')
title('Rep 3: Product of individual probability distributions')
subplot(2,1,2),imagesc(centers,centers,cnt_norm_3)
xlabel('Phase (degrees)')
ylabel('Phase (degrees)')
title('Rep 3: Normalized joint probability')

figure
subplot(2,1,1),imagesc(centers,centers,prod_norm_4)
xlabel('Phase (degrees)')
ylabel('Phase (degrees)')
title('Rep 4: Product of individual probability distributions')
subplot(2,1,2),imagesc(centers,centers,cnt_norm_4)
xlabel('Phase (degrees)')
ylabel('Phase (degrees)')
title('Rep 4: Normalized joint probability')

figure
subplot(2,1,1),imagesc(centers,centers,prod_norm_5)
xlabel('Phase (degrees)')
ylabel('Phase (degrees)')
title('Rep 5: Product of individual probability distributions')
subplot(2,1,2),imagesc(centers,centers,cnt_norm_5)
xlabel('Phase (degrees)')
ylabel('Phase (degrees)')
title('Rep 5: Normalized joint probability')

figure
subplot(2,1,1),imagesc(centers,centers,prod_norm_15)
xlabel('Phase (degrees)')
ylabel('Phase (degrees)')
title('Rep 1+5: Product of individual probability distributions')
subplot(2,1,2),imagesc(centers,centers,cnt_norm_15)
xlabel('Phase (degrees)')
ylabel('Phase (degrees)')
title('Rep 1+5: Normalized joint probability')

figure
subplot(2,1,1),imagesc(centers,centers,prod_norm_51)
xlabel('Phase (degrees)')
ylabel('Phase (degrees)')
title('Rep 5+1: Product of individual probability distributions')
subplot(2,1,2),imagesc(centers,centers,cnt_norm_51)
xlabel('Phase (degrees)')
ylabel('Phase (degrees)')
title('Rep 5+1: Normalized joint probability')

%% Probability distributions averaged across reps
all_prod_norm(:,:,1)=prod_norm_1;
all_prod_norm(:,:,2)=prod_norm_2;
all_prod_norm(:,:,3)=prod_norm_3;
all_prod_norm(:,:,4)=prod_norm_4;
all_prod_norm(:,:,5)=prod_norm_5;

prod_norm_mean=mean(all_prod_norm,3);

all_cnt_norm(:,:,1)=cnt_norm_1;
all_cnt_norm(:,:,2)=cnt_norm_2;
all_cnt_norm(:,:,3)=cnt_norm_3;
all_cnt_norm(:,:,4)=cnt_norm_4;
all_cnt_norm(:,:,5)=cnt_norm_5;

cnt_norm_mean=mean(all_cnt_norm,3);

figure
subplot(2,1,1),imagesc(centers,centers,prod_norm_mean)
xlabel('Phase (degrees)')
ylabel('Phase (degrees)')
title('Mean over all reps: Product of individual probability distributions')
subplot(2,1,2),imagesc(centers,centers,cnt_norm_mean)
xlabel('Phase (degrees)')
ylabel('Phase (degrees)')
title('Mean over all reps: Normalized joint probability')
%% First-last probability distributions averaged
cnt_norm_fl(:,:,1)=cnt_norm_15;
cnt_norm_fl(:,:,2)=cnt_norm_51;

cnt_norm_fl_mean=mean(cnt_norm_fl,3);

prod_norm_fl(:,:,1)=prod_norm_15;
prod_norm_fl(:,:,2)=prod_norm_51;

prod_norm_fl_mean=mean(prod_norm_fl,3);

figure
subplot(2,1,1),imagesc(centers,centers,prod_norm_fl_mean)
xlabel('Phase (degrees)')
ylabel('Phase (degrees)')
title('Mean of 1+5 and 5+1: Product of individual probability distributions')
subplot(2,1,2),imagesc(centers,centers,cnt_norm_fl_mean)
xlabel('Phase (degrees)')
ylabel('Phase (degrees)')
title('Mean of 1+5 and 5+1: Normalized joint probability')

%% Circular correlation
for i=1:nreps
      [r(i),p(i),ts(i)]=circ_corrcc(inst_phase_r(i,:),inst_phase_s(i,:));
end

[n_15 r_15 r2_15 ts_15 p_15]=circ_corrcc(inst_phase_r_deg(1,:),inst_phase_s_deg(5,:));
[n_51 r_51 r2_51 ts_51 p_51]=circ_corrcc(inst_phase_r_deg(5,:),inst_phase_s_deg(1,:));
'r:'
r'
'r2:'
r.^2'
't:'
ts'
'p:'
p'

'First and last rep comparisons: 1+5 then 5+1:'
'r'
rs=[r_15
r_51]
'r2'
r2s=[r2_15
r2_51]
't'
tss=[ts_15
ts_51]
'p'
ps=[p_15
p_51]