function varargout = KOrecord_CAB(varargin)

%
% KOrecord_CAB.m
%   Stimulates Knollenorgans and records spiking responses
%
%   For use with Tucker-Davis Technologies System 3, using 2 RP2.1
%   processors and 1 PA5 programmable attenuator
%
%   CONNECTIONS:
%       RP2.1-1 OUT1 ... to PA5 INPUT
%       PA5 OUTPUT ... to A-M Systems 1600 recording amplifier current input
%       RP2.1-1 IN1 ... from A-M Systems 1800 recording amplifier Channel 1 voltage output
%       RP2.1-1 IN2 ... from A-M Systems 1800 recording amplifier Channel 2 voltage output
%       RP2.1-2 IN1 ... from A-M Systems 1600 recording amplifier voltage output
%       RP2.1-2 IN2 ... from A-M Systems 1600 recording amplifier current monitor
%

%% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @KOrecord_CAB_OpeningFcn, ...
                   'gui_OutputFcn',  @KOrecord_CAB_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end

%% Executes just before KOrecord_CAB is made visible.
function KOrecord_CAB_OpeningFcn(hObject, eventdata, handles, varargin)

%% Choose default command line output for KOrecord_CAB
handles.output = hObject;

%% Update handles structure
guidata(hObject, handles);

%% Outputs from this function are returned to the command line.
function varargout = KOrecord_CAB_OutputFcn(hObject, eventdata, handles) 

%% Get default command line output from handles structure
varargout{1} = handles.output;

%% Initialization
axes(handles.axes_stim);
ylabel('Stim Amp (nA)','FontSize',12)
xlabel('Time (ms)','FontSize',12)
axes(handles.axes_response);
ylabel('Resp Amp (mV)','FontSize',12)
set(handles.axes_response,'XTickLabel',[])
axes(handles.axes_spikes);
ylabel('Number of Spikes','FontSize',12)
set(handles.axes_spikes,'XTickLabel',[])
linkaxes([handles.axes_stim handles.axes_response handles.axes_spikes],'x')

%% PLAY/REC TOGGLEBUTTON - Play Stimulus and Record Response
function togglebutton_playrec_Callback(hObject, eventdata, handles)
global srate_stm srate_rec stimulus response stimwave srate_wavstim pulsetype tonefreq pulsedur pulseint pulseatt pulsepol prestimdur pststimdur ampgain vcconv curmon spktimes spkamps spktimes_byrep spkamps_byrep spktimesinwin_byrep spkampsinwin_byrep wavfilename
button_state = get(hObject,'Value');
if button_state == get(hObject,'Max'),
    set(hObject,'ForegroundColor',[0 0 0]);
    stim_run = 1;
    KOrecord_playrec;
elseif button_state == get(hObject,'Min'),
    set(hObject,'ForegroundColor',[1 1 1]);
    stim_run = 0;
end

%% PLAY TOGGLEBUTTON - Play Stimulus
function togglebutton_play_Callback(hObject, eventdata, handles)
global stimwave srate_wavstim srate_stm srate_rec stimulus response pulsetype tonefreq pulsedur pulseint pulseatt pulsepol prestimdur pststimdur ampgain vcconv curmon spktimes spkamps spktimes_byrep spkamps_byrep spktimesinwin_byrep spkampsinwin_byrep wavfilename
button_state = get(hObject,'Value');
if button_state == get(hObject,'Max'),
    set(hObject,'ForegroundColor',[0 0 0]);
    stim_run = 1;
    KOrecord_play;
elseif button_state == get(hObject,'Min'),
    set(hObject,'ForegroundColor',[1 1 1]);
    stim_run = 0;
end


%% REC2 TOGGLEBUTTON - Record from 2 Channels
function togglebutton_rec2chan_Callback(hObject, eventdata, handles)
global srate_stm srate_rec stimulus response stimwave srate_wavstim pulsetype tonefreq pulsedur pulseint pulseatt pulsepol prestimdur pststimdur ampgain vcconv curmon spktimes spkamps spktimes_byrep spkamps_byrep spktimesinwin_byrep spkampsinwin_byrep wavfilename
button_state = get(hObject,'Value');
if button_state == get(hObject,'Max'),
    set(hObject,'ForegroundColor',[0 0 0]);
    stim_run = 1;
    KOrecord_rec2chan;
elseif button_state == get(hObject,'Min'),
    set(hObject,'ForegroundColor',[1 1 1]);
    stim_run = 0;
end

%% SAVE PUSHBUTTON - Save data to file
function pushbutton_save_Callback(hObject, eventdata, handles)
global srate_stm srate_rec stimulus response pulsetype tonefreq pulsedur pulseint pulseatt pulsepol prestimdur pststimdur ampgain vcconv curmon spktimes spkamps spktimes_byrep spkamps_byrep spktimesinwin_byrep spkampsinwin_byrep wavfilename
[filename,pathname] = uiputfile('*.wave.KOrec.mat','Enter file name');
if pathname == 0
    beep
    return
end
species_array = get(handles.popupmenu_species, 'String');
species = char(species_array(get(handles.popupmenu_species, 'Value')));
sex_array = get(handles.popupmenu_sex,'String');
sex = char(sex_array(get(handles.popupmenu_sex, 'Value')));
totallength = str2num(get(handles.edit_totallength,'String'));
temperature = str2num(get(handles.edit_temperature,'String'));
conductivity = str2num(get(handles.edit_conductivity,'String'));
wavfilename = get(handles.text_wavfile,'String');
addinfo = get(handles.edit_addinfo,'String');
save (fullfile(pathname,filename), 'srate_stm', 'srate_rec', 'pulsetype', 'tonefreq', 'pulsedur', 'pulseint', 'pulseatt', 'pulsepol', 'prestimdur', 'pststimdur', 'species', 'sex', 'totallength', 'temperature', 'conductivity', 'wavfilename', 'addinfo', 'stimulus', 'response', 'ampgain', 'vcconv', 'curmon');

%% LOAD PUSHBUTTON - Loads saved data
function pushbutton_load_Callback(hObject, eventdata, handles)
global srate_stm srate_rec stimulus response pulsetype tonefreq pulsedur pulseint pulseatt pulsepol prestimdur pststimdur ampgain vcconv curmon spktimes spkamps spktimes_byrep spkamps_byrep spktimesinwin_byrep spkampsinwin_byrep wavfilename
[filename, pathname] = uigetfile('*.wave.KOrec.mat', 'Open data file');
if pathname == 0
    beep
    return
end
load (fullfile(pathname,filename), '-mat');
cd(char(pathname))
species_options = get(handles.popupmenu_species,'String');
quit = 0;
i = 1;
while quit==0,
    if size(char(species_options(i)))==size(species),
        if species==char(species_options(i)),
            set(handles.popupmenu_species,'Value',i);
            quit = 1;
        end
    end
    i = i+1;
end
sex_options = get(handles.popupmenu_sex,'String');
quit = 0;
i = 1;
while quit==0,
    if size(char(sex_options(i)))==size(sex),
        if sex==char(sex_options(i)),
            set(handles.popupmenu_sex,'Value',i);
            quit = 1;
        end
    end
    i = i+1;
end
set(handles.edit_totallength, 'String', totallength);
set(handles.edit_temperature, 'String', temperature);
set(handles.edit_conductivity, 'String', conductivity);
set(handles.text_wavfile,'String',wavfilename);
set(handles.edit_addinfo, 'String', addinfo);
pulse_options = get(handles.popupmenu_pulsetype,'String');
quit = 0;
i = 1;
while quit==0,
    if size(char(pulse_options(i)))==size(pulsetype),
        if pulsetype==char(pulse_options(i)),
            set(handles.popupmenu_pulsetype,'Value',i);
            quit = 1;
        end
    end
    i = i+1;
end
pulsepol_options = get(handles.popupmenu_pulsepol,'String');
quit = 0;
i = 1;
while quit==0,
    if size(char(pulsepol_options(i)))==size(pulsepol),
        if pulsepol==char(pulsepol_options(i)),
            set(handles.popupmenu_pulsepol,'Value',i);
            quit = 1;
        end
    end
    i = i+1;
end
if exist('tonefreq')==1,
    set(handles.edit_tonefreq, 'String', tonefreq);
else
    set(handles.edit_tonefreq, 'String', '');
end
set(handles.edit_pulsedur, 'String', pulsedur);
set(handles.edit_pulseint, 'String', pulseint);
set(handles.edit_pulseatt, 'String', pulseatt);
pulsevolt = 10*(10^(-pulseatt/20));
set(handles.text_voltout,'String',['= ' num2str(pulsevolt) ' V']);
set(handles.edit_ampgain, 'String', ampgain);
if (vcconv==10)&(curmon==10),
    set(handles.popupmenu_currange,'Value',2);
elseif (vcconv==100)&(curmon==1),
    set(handles.popupmenu_currange,'Value',3);
else
    set(handles.popupmenu_currange,'Value',1);
end
set(handles.edit_prestimdur, 'String', prestimdur);
set(handles.edit_pststimdur, 'String', pststimdur);
samptime = [1:1:length(response)].*(1000/srate_rec);
[m_rsp,n_rsp] = size(response);
nreps = m_rsp;
if nreps==1,
    set(handles.text_numreps,'String',[num2str(nreps) ' Repetition'])
else
    set(handles.text_numreps,'String',[num2str(nreps) ' Repetitions'])
end
plot(handles.axes_stim,samptime,stimulus,'k-')
ylabel(handles.axes_stim,'Stim Amp (nA)','FontSize',12)
xlabel(handles.axes_stim,'Time (ms)','FontSize',12)
plot(handles.axes_response,samptime,response,'k-')
ylabel(handles.axes_response,'Resp Amp (mV)','FontSize',12)
set(handles.axes_response,'XTickLabel',[])
zoom reset
zoom on

%% Get Spikes
function pushbutton_getspikes_Callback(hObject, eventdata, handles)
global srate_stm srate_rec stimulus response stimwave srate_wavstim pulsetype tonefreq pulsedur pulseint pulseatt pulsepol prestimdur pststimdur ampgain vcconv curmon spktimes spkamps spktimes_byrep spkamps_byrep spktimesinwin_byrep spkampsinwin_byrep wavfilename
KOrecord_spkdetect_CAB

%% Remove Spikes
function pushbutton_delspikes_Callback(hObject, eventdata, handles)
global srate_stm srate_rec stimulus response stimwave srate_wavstim pulsetype tonefreq pulsedur pulseint pulseatt pulsepol prestimdur pststimdur ampgain vcconv curmon spktimes spkamps spktimes_byrep spkamps_byrep spktimesinwin_byrep spkampsinwin_byrep wavfilename
KOrecord_spkdelete_CAB

%% Count Spikes
function pushbutton_cntspikes_Callback(hObject, eventdata, handles)
global srate_stm srate_rec stimulus response stimwave srate_wavstim pulsetype tonefreq pulsedur pulseint pulseatt pulsepol prestimdur pststimdur ampgain vcconv curmon spktimes spkamps spktimes_byrep spkamps_byrep spktimesinwin_byrep spkampsinwin_byrep wavfilename
KOrecord_spkcount_CAB

%% Measure First-spike Latency
function pushbutton_spklatency_Callback(hObject, eventdata, handles)
global srate_stm srate_rec stimulus response stimwave srate_wavstim pulsetype tonefreq pulsedur pulseint pulseatt pulsepol prestimdur pststimdur ampgain vcconv curmon spktimes spkamps spktimes_byrep spkamps_byrep spktimesinwin_byrep spkampsinwin_byrep wavfilename
KOrecord_spklatency

%% Measure inter-spike intervals (ISI)
function pushbutton_isi_Callback(hObject, eventdata, handles)
global srate_stm srate_rec stimulus response stimwave srate_wavstim pulsetype tonefreq pulsedur pulseint pulseatt pulsepol prestimdur pststimdur ampgain vcconv curmon spktimes spkamps spktimes_byrep spkamps_byrep spktimesinwin_byrep spkampsinwin_byrep wavfilename
KOrecord_isi

%% Measure cross-correlation coefficient between recordings on 2 channels
function pushbutton_2chancorr_Callback(hObject, eventdata, handles)
global srate_stm srate_rec stimulus response stimwave srate_wavstim pulsetype tonefreq pulsedur pulseint pulseatt pulsepol prestimdur pststimdur ampgain vcconv curmon spktimes spkamps spktimes_byrep spkamps_byrep spktimesinwin_byrep spkampsinwin_byrep wavfilename
KOrecord_2chancorr

%% Measure Frequency Power Spectrum
function pushbutton_fft_Callback(hObject, eventdata, handles)
global srate_stm srate_rec stimulus response stimwave srate_wavstim pulsetype tonefreq pulsedur pulseint pulseatt pulsepol prestimdur pststimdur ampgain vcconv curmon spktimes spkamps spktimes_byrep spkamps_byrep spktimesinwin_byrep spkampsinwin_byrep wavfilename
KOrecord_fft

%% Measure spontaneous activity
function pushbutton_spont_Callback(hObject, eventdata, handles)
global srate_stm srate_rec stimulus response stimwave srate_wavstim pulsetype tonefreq pulsedur pulseint pulseatt pulsepol prestimdur pststimdur ampgain vcconv curmon spktimes spkamps spktimes_byrep spkamps_byrep spktimesinwin_byrep spkampsinwin_byrep wavfilename
KOrecord_spont

%% Choose Type of Pulse
function popupmenu_pulsetype_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function popupmenu_pulsetype_Callback(hObject, eventdata, handles)
global stimwave srate_wavstim wavfilename
pulse_type_array = get(handles.popupmenu_pulsetype, 'String');
pulsetype = char(pulse_type_array(get(handles.popupmenu_pulsetype, 'Value')));
switch pulsetype
    case 'Load Waveform File'
        [filename_wavstim, pathname_wavstim] = uigetfile('*.stim.wav.mat', 'Open stimulus waveform file...');
        load (fullfile(pathname_wavstim,filename_wavstim), '-mat');
        set(handles.text_wavfile,'String',fullfile(pathname_wavstim,filename_wavstim));
        srate_wavstim = srate;
        set(handles.edit_pulsedur,'String',[]);
        set(handles.edit_tonefreq,'String',[]);
    otherwise
        set(handles.text_wavfile,'String',[]);
end

%% Set Interpulse Interval for Paired Pulses
function edit_pulseint_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function edit_pulseint_Callback(hObject, eventdata, handles)

%% Set Tone Frequency
function edit_tonefreq_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function edit_tonefreq_Callback(hObject, eventdata, handles)

%% Set Pulse Duration
function edit_pulsedur_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function edit_pulsedur_Callback(hObject, eventdata, handles)

%% Set Pulse Attenuation
function edit_pulseatt_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function edit_pulseatt_Callback(hObject, eventdata, handles)
pulseatt = str2num(get(handles.edit_pulseatt,'String'));
if pulseatt>120.0,
    set(handles.edit_pulseatt,'String','');
    set(handles.text_voltout,'String','');
    error('Pulse Attenuation Cannot Exceed 120.0 dB!!!')
end
pulsevolt = 10*(10^(-pulseatt/20));
set(handles.text_voltout,'String',['= ' num2str(pulsevolt) ' V']);

%% Choose Pulse Polarity
function popupmenu_pulsepol_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function popupmenu_pulsepol_Callback(hObject, eventdata, handles)

%% Enter Amplifier Gain
function edit_ampgain_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function edit_ampgain_Callback(hObject, eventdata, handles)

%% Set Current Injection Range
function popupmenu_currange_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function popupmenu_currange_Callback(hObject, eventdata, handles)

%% Set Pre-Stimulus Duration
function edit_prestimdur_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function edit_prestimdur_Callback(hObject, eventdata, handles)

%% Set Post-Stimulus Duration
function edit_pststimdur_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function edit_pststimdur_Callback(hObject, eventdata, handles)


%% Enter Number of Repetitions
function edit_setnumreps_Callback(hObject, eventdata, handles)
function edit_setnumreps_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

%% Choose Species
function popupmenu_species_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function popupmenu_species_Callback(hObject, eventdata, handles)

%% Choose Sex
function popupmenu_sex_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function popupmenu_sex_Callback(hObject, eventdata, handles)

%% Enter Total Length
function edit_totallength_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function edit_totallength_Callback(hObject, eventdata, handles)

%% Enter Temperature
function edit_temperature_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function edit_temperature_Callback(hObject, eventdata, handles)

%% Enter Conductivity
function edit_conductivity_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function edit_conductivity_Callback(hObject, eventdata, handles)

%% Enter Additional info
function edit_addinfo_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
function edit_addinfo_Callback(hObject, eventdata, handles)










